// Copyright (c) Mito
import React from 'react';
import '../../css/column-header.css';
import { getHeaderWords } from '../utils/gridStyling';
import { getTypeIcon } from './graphs/ColumnSelectorColumnCard';
import { FilterEmptyIcon, FilterNonEmptyIcon } from './icons/FilterIcons';
import { ControlPanelTab } from './taskpanes/ControlPanel/ControlPanelTaskpane';
import { TaskpaneType } from './taskpanes/taskpanes';
/*
  A custom component that AG-Grid displays for the column
  header, that we extend to open the column header popup when clicked.

  NOTE: When you add a prop to this component, you must also pass it as a header
  prop, wherever the column is constructed.
*/
const ColumnHeader = (props) => {
    /*
      we split each word of the header (separated by _) into its own span element, adding the _ to
      the latter half of the split. ie: first_name -> [first, _name]
      This lets us wrap the column headers without breaking words in half, which we would
      do if we just used a fix length cutoff for each row as the cutoff.

      Note: this behaves better when the header's words are <10 characters, but worse when
      the header's words are > 10 characters. The 10 number is decided by the default column width
    */
    const wordsSpans = getHeaderWords(props.columnHeader).map(word => {
        // give the span a random key. we don't use the word because there may be duplicates
        return (React.createElement("span", { key: Math.random() }, word));
    });
    const openControlPanelToFilter = () => {
        props.setCurrOpenTaskpane({
            type: TaskpaneType.CONTROL_PANEL,
            columnHeader: props.columnHeader,
            openEditingColumnHeader: false,
        });
        props.setSelectedColumnControlPanelTab(ControlPanelTab.FilterSort);
    };
    return (React.createElement("div", { className: 'column-header-cell', onClick: () => {
            props.setSelectedColumn(props.columnHeader);
        } },
        React.createElement("div", { className: 'column-header-header-container' },
            React.createElement("div", { onClick: () => {
                    props.setCurrOpenTaskpane({
                        type: TaskpaneType.CONTROL_PANEL,
                        columnHeader: props.columnHeader,
                        openEditingColumnHeader: true
                    });
                }, className: "column-header-column-header mr-1" }, wordsSpans)),
        React.createElement("div", { className: 'column-header-icon-container' },
            React.createElement("div", { onClick: openControlPanelToFilter },
                props.filters.length === 0 &&
                    React.createElement(FilterEmptyIcon, null),
                props.filters.length !== 0 &&
                    React.createElement(FilterNonEmptyIcon, null)),
            React.createElement("div", { onClick: openControlPanelToFilter }, getTypeIcon(props.columnMitoType)))));
};
export default ColumnHeader;
//# sourceMappingURL=ColumnHeader.js.map